@@ -2,7 +2,7 @@
 
 import os
 import sys
-import stat # file permissions
+import stat  # file permissions
 import shutil
 import argparse
 from argparse import RawTextHelpFormatter
@@ -14,10 +14,12 @@ def help_string():
     overview = 'This is a convenience script for auto-generating a catkin workspace.\n\n'
     instructions = "It acts on the specified directory (or the current directory if unspecified) and creates:\n\n \
  - ./src : initialised with a catkin CMakeLists.txt and a wstool .rosinstall file.\n \
- - ./debug : for native build temporaries\n \
- - ./devel : for a native runtime area.\n \
- - ./cross : for cross compiled build temporaries. \n \
- - ./fakeroot : for cross compiled installs. \n \
+ - ./debug : for native debug temporaries\n \
+ - ./debug/devel : for a native debug runtime area.\n \
+ - ./debug/install : for a native debug install area.\n \
+ - ./release : for native release temporaries\n \
+ - ./cross-debug : for parallel cross-compiled debug temporaries\n \
+ - ./cross-release : for parallel cross-compiled release temporaries\n \
 "
     return overview + instructions
 
@@ -34,8 +36,10 @@ def create_groovy_script(script_name):
 
 def parse_arguments():
     parser = argparse.ArgumentParser(description=help_string(), formatter_class=RawTextHelpFormatter)
-    parser.add_argument('dir', nargs='?', default=os.getcwd(), help='directory to use for the workspace [default: current working directory]')
-    parser.add_argument('-c', '--cross', action='store_true', help='install cross-compiling build directories')
+    parser.add_argument('dir', nargs='?', default=os.getcwd(), help='directory to use for the workspace [current working directory]')
+    parser.add_argument('-c', '--cross', action='store_true', help='install cross-compiling build directories [false]')
+    parser.add_argument('-o', '--overlay', action='store', default='/opt/ros/groovy', help='directory on top of which to overlay [/opt/ros/groovy]')
+    parser.add_argument('-s', '--simple', action='store_true', help='just create a basic single build workspace (usual ros style) [false]')
     args = parser.parse_args()
     return args
 
@@ -66,14 +70,14 @@ def read_template(tmplf):
     return t
 
 
-def fill_in_template(template, name, cwd):
+def fill_in_template(template, name, cwd, overlay):
     return template % locals()
 
 
-def instantiate_template(filename, name, cwd):
+def instantiate_template(filename, name, cwd, overlay):
     template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_workspace')
     tmpl = read_template(os.path.join(template_dir, filename))
-    contents = fill_in_template(tmpl, name, cwd)
+    contents = fill_in_template(tmpl, name, cwd, overlay)
     try:
         f = open(os.path.join(cwd, filename), 'w')
         f.write(contents.encode('utf-8'))
@@ -108,27 +112,29 @@ def init_workspace():
 
     os.mkdir(os.path.join(workspace_dir, 'src'))
     os.chdir(os.path.join(workspace_dir, 'src'))
-    os.system('wstool init')
+    os.system('wstool init . ' + args.overlay)
     catkin_init_workspace = create_groovy_script('catkin_init_workspace')
     unused_process = subprocess.call(catkin_init_workspace.name, shell=True)
     os.chdir(workspace_dir)
 
-    # Create build directories
-    os.mkdir(os.path.join(workspace_dir, 'debug'))
-    os.mkdir(os.path.join(workspace_dir, 'release'))
-    if args.cross:
-        init_cross_workspace(workspace_dir)
-
     template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_workspace')
-    shutil.copy(os.path.join(template_dir, 'Makefile'), os.path.join(workspace_dir, 'debug'))
-    shutil.copy(os.path.join(template_dir, 'Makefile-Release'), os.path.join(workspace_dir, 'release', 'Makefile'))
 
-    shutil.copy(os.path.join(template_dir, 'setup.bash'), workspace_dir)
-    os.chmod(os.path.join(workspace_dir, 'setup.bash'), stat.S_IRWXU)
+    if not args.simple:
+        # Create build directories
+        os.mkdir(os.path.join(workspace_dir, 'debug'))
+        os.mkdir(os.path.join(workspace_dir, 'release'))
+        if args.cross:
+            init_cross_workspace(workspace_dir)
+        shutil.copy(os.path.join(template_dir, 'Makefile'), os.path.join(workspace_dir, 'debug'))
+        shutil.copy(os.path.join(template_dir, 'Makefile-Release'), os.path.join(workspace_dir, 'release', 'Makefile'))
+
     name = os.path.basename(workspace_dir)
-    instantiate_template('.bashrc', name, workspace_dir)
-    instantiate_template('konsole', name, workspace_dir)
-    instantiate_template('gnome-terminal', name, workspace_dir)
-    instantiate_template('eclipse', name, workspace_dir)
+    #shutil.copy(os.path.join(template_dir, 'setup.bash'), workspace_dir)
+    instantiate_template('setup.bash', name, workspace_dir, args.overlay)
+    os.chmod(os.path.join(workspace_dir, 'setup.bash'), stat.S_IRWXU)
+    instantiate_template('.bashrc', name, workspace_dir, args.overlay)
+    instantiate_template('konsole', name, workspace_dir, args.overlay)
+    instantiate_template('gnome-terminal', name, workspace_dir, args.overlay)
+    instantiate_template('eclipse', name, workspace_dir, args.overlay)
 
     os.unlink(catkin_init_workspace.name)
